@@ -434,6 +434,15 @@ INVALIDPARAMETERVALUE_VPCCIDRCONFLICT = 'InvalidParameterValue.VpcCidrConflict'
 # 当前功能不支持此专线网关。
 INVALIDPARAMETERVALUE_VPGTYPENOTMATCH = 'InvalidParameterValue.VpgTypeNotMatch'
 
+# 当前BGP隧道网段：`%(key)s`和已有BGP隧道网段：`%(value)s`重叠。
+INVALIDPARAMETERVALUE_VPNCONNBGPTUNNELCIDRCONFLICT = 'InvalidParameterValue.VpnConnBgpTunnelCidrConflict'
+
+# BGP隧道网段必须为掩码为30的网段。
+INVALIDPARAMETERVALUE_VPNCONNBGPTUNNELCIDRMASK = 'InvalidParameterValue.VpnConnBgpTunnelCidrMask'
+
+# 云端或用户端BGP地址：`%(value)s`必须在BGP隧道网段`%(key)s`内。
+INVALIDPARAMETERVALUE_VPNCONNBGPTUNNELCIDRNOTSUPPORTED = 'InvalidParameterValue.VpnConnBgpTunnelCidrNotSupported'
+
 # 目的网段和当前VPN通道的CIDR冲突。
 INVALIDPARAMETERVALUE_VPNCONNCIDRCONFLICT = 'InvalidParameterValue.VpnConnCidrConflict'
 
@@ -521,12 +530,18 @@ LIMITEXCEEDED_MODIFYADDRESSINTERNETCHARGETYPEQUOTA = 'LimitExceeded.ModifyAddres
 # 每月地址找回配额超过限制。
 LIMITEXCEEDED_MONTHLYADDRESSRECOVERYQUOTA = 'LimitExceeded.MonthlyAddressRecoveryQuota'
 
+# NAT网关的DNAT转换规则数量已达到上限。
+LIMITEXCEEDED_NATGATEWAYDNATLIMITEXCEEDED = 'LimitExceeded.NatGatewayDnatLimitExceeded'
+
 # NAT网关数量已达到上限。
 LIMITEXCEEDED_NATGATEWAYLIMITEXCEEDED = 'LimitExceeded.NatGatewayLimitExceeded'
 
 # 私有网络创建的NAT网关超过上限。
 LIMITEXCEEDED_NATGATEWAYPERVPCLIMITEXCEEDED = 'LimitExceeded.NatGatewayPerVpcLimitExceeded'
 
+# VPC内创建的弹性网卡数量超过上限
+LIMITEXCEEDED_NETWORKINTERFACELIMITEXCEEDED = 'LimitExceeded.NetworkInterfaceLimitExceeded'
+
 # 过滤参数名称超过限制。
 LIMITEXCEEDED_NUMBEROFFILTERS = 'LimitExceeded.NumberOfFilters'
 
@@ -587,6 +602,9 @@ RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 # 网段资源不足。
 RESOURCEINSUFFICIENT_CIDRBLOCK = 'ResourceInsufficient.CidrBlock'
 
+# 指定实例类型已售罄。
+RESOURCEINSUFFICIENT_INSTANCE = 'ResourceInsufficient.Instance'
+
 # 子网IP资源不足, 无法分配IP。
 RESOURCEINSUFFICIENT_SUBNET = 'ResourceInsufficient.Subnet'
 
@@ -854,6 +872,9 @@ UNSUPPORTEDOPERATION_NATGATEWAYEIPNOTEXISTS = 'UnsupportedOperation.NatGatewayEi
 # NAT网关存在未解绑的IP。
 UNSUPPORTEDOPERATION_NATGATEWAYHADEIPUNASSOCIATE = 'UnsupportedOperation.NatGatewayHadEipUnassociate'
 
+# NAT网关已被封禁，不支持此操作。
+UNSUPPORTEDOPERATION_NATGATEWAYRESTRICTED = 'UnsupportedOperation.NatGatewayRestricted'
+
 # SNAT/DNAT转换规则所指定的内网IP已绑定了其他的规则，无法重复绑定。
 UNSUPPORTEDOPERATION_NATGATEWAYRULEPIPEXISTS = 'UnsupportedOperation.NatGatewayRulePipExists'
 
@@ -893,6 +914,9 @@ UNSUPPORTEDOPERATION_NOTSUPPORTDELETEDEFAULTROUTETABLE = 'UnsupportedOperation.N
 # 公有云到黑石的对等连接不支持删除。
 UNSUPPORTEDOPERATION_NOTSUPPORTDELETEVPCBMPEER = 'UnsupportedOperation.NotSupportDeleteVpcBmPeer'
 
+# 不支持的可用区
+UNSUPPORTEDOPERATION_NOTSUPPORTZONE = 'UnsupportedOperation.NotSupportZone'
+
 # 该地址类型不支持释放操作。
 UNSUPPORTEDOPERATION_NOTSUPPORTEDADDRESSIPSCHARGETYPE = 'UnsupportedOperation.NotSupportedAddressIpsChargeType'
 
@@ -947,6 +971,9 @@ UNSUPPORTEDOPERATION_RESOURCEMISMATCH = 'UnsupportedOperation.ResourceMismatch'
 # 未找到相关角色，请确认角色是否授权。
 UNSUPPORTEDOPERATION_ROLENOTFOUND = 'UnsupportedOperation.RoleNotFound'
 
+# 当前路由表删除失败，请先检查是否存在关联的策略。
+UNSUPPORTEDOPERATION_ROUTETABLECANNOTDELETE = 'UnsupportedOperation.RouteTableCanNotDelete'
+
 # 路由表绑定了子网。
 UNSUPPORTEDOPERATION_ROUTETABLEHASSUBNETRULE = 'UnsupportedOperation.RouteTableHasSubnetRule'
 
@@ -1064,6 +1091,21 @@ UNSUPPORTEDOPERATION_VPNCONNSPDOVERLAP = 'UnsupportedOperation.VpnConnSPDOverlap
 # VPC类型VPN网关必须携带VpcId。
 UNSUPPORTEDOPERATION_VPNGWVPCIDMUSTHAVE = 'UnsupportedOperation.VpnGwVpcIdMustHave'
 
+# VPN不支持BGP
+UNSUPPORTEDOPERATION_VPNUNSUPPORTEDBGP = 'UnsupportedOperation.VpnUnsupportedBgp'
+
+# 对端网关BGP ASN和已有的通道对端或云上VPN的BGP ASN相同。
+UNSUPPORTEDOPERATION_VPNUNSUPPORTEDBGPASNEQUAL = 'UnsupportedOperation.VpnUnsupportedBgpAsnEqual'
+
+# `%(value)s`，不支持降低VPN带宽。
+UNSUPPORTEDOPERATION_VPNUNSUPPORTEDMODIFYBANDWIDTH = 'UnsupportedOperation.VpnUnsupportedModifyBandwidth'
+
+# VPN不支持修改BGP ASN。
+UNSUPPORTEDOPERATION_VPNUNSUPPORTEDMODIFYBGPASN = 'UnsupportedOperation.VpnUnsupportedModifyBgpAsn'
+
+# VPN未配置BGP ASN。
+UNSUPPORTEDOPERATION_VPNUNSUPPORTEDNOTEXISTBGPASN = 'UnsupportedOperation.VpnUnsupportedNotExistBgpAsn'
+
 # 指定资源在不同的可用区。
 UNSUPPORTEDOPERATION_ZONEMISMATCH = 'UnsupportedOperation.ZoneMismatch'
 
